import { Component, Input, OnInit, Output, EventEmitter } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { ButtonType } from '../../../../shared/components/button/buttonType.enum';
import { Category } from '../../../../structure-list/models/category.model';
import { Module } from '../../../../structure-list/models/module.model';
import { SearchService } from '../../../../structure-list/services/search.service';

@Component({
  selector: 'app-online-demarch',
  templateUrl: './online-demarch.component.html',
  styleUrls: ['./online-demarch.component.scss'],
})
export class OnlineDemarchComponent implements OnInit {
  @Input() form: UntypedFormGroup;
  @Output() checkValidation = new EventEmitter<any>();
  constructor(private searchService: SearchService) {}
  public accompanimentType: Module[];
  public buttonTypeEnum = ButtonType;
  public selectedModules: Module[] = [];

  ngOnInit(): void {
    this.selectedModules = this.form.get('onlineDemarchType').value;
    this.searchService.getCategoriesAccompaniment().subscribe((categories: Category[]) => {
      this.accompanimentType = categories[0].modules;
    });
    this.checkValidation.emit();
  }

  public handleClick(module: Module): void {
    if (this.isSelectedModule(module.id)) {
      const index = this.selectedModules.findIndex((_module) => _module.id === module.id);
      this.selectedModules.splice(index, 1);
    } else {
      this.selectedModules.push(module);
    }
    this.form.get('onlineDemarchType').patchValue(this.selectedModules);
    this.checkValidation.emit();
  }

  public isSelectedModule(moduleId: string): boolean {
    if (this.selectedModules && this.selectedModules.map((module) => module.id).includes(moduleId)) return true;
    return false;
  }
}
